@@ -1,7 +1,17 @@
 import os
 
-WORKER_LOG_FILE_DIR = os.path.expanduser("~")
-"""Directory to save worker log files."""
+import appdirs
+
+from pyqalx.core.utils import APPNAME, APPAUTHOR
+
+WORKER_LOG_FILE_DIR = os.path.join(appdirs.user_log_dir(APPNAME, APPAUTHOR))
+r"""Directory to save worker log files
+
+* Windows: C:\\Users\\<User>\\AppData\\Local\\agiletek\\qalx\\Logs
+* Linux: /home/<user>/.cache/qalx/log
+* Max ~/Library/Logs/qalx
+
+"""
 
 SAVE_INTERMITTENT = False
 """Save the entity after every processing step?"""
@@ -26,3 +36,5 @@ The maximum wait time will be ``Q_WAITTIMEMAXSPREADING*Q_WAITTIMESECONDS``."""
 
 MSG_WAITTIMESECONDS = 20
 """The time in seconds the bot will wait for a message to appear in the queue"""
+
+del APPNAME, APPAUTHOR  # These are not config keys
