@@ -7,6 +7,7 @@ from bson_extra import bson_extra
 from pyqalx.config import UserConfig, BotConfig
 from pyqalx.core.entities import QalxListEntity
 from pyqalx.core.entities.entity import AggregationResult
+from pyqalx.core.enums import ValidStates
 from pyqalx.core.errors import (
     QalxError,
     QalxNoGUIDError,
@@ -1049,3 +1050,16 @@ class QalxUpdateStatusAdapter(QalxAdapter):
         )
         status_dict = {"message": status}
         self._process_api_request("patch", endpoint, status=status_dict)
+
+
+class QalxUpdateStateAdapter(QalxAdapter):
+    def update_state(self, entity, state: ValidStates, **kwargs):
+        """
+        Helper to update the state of a bot or worker. The API handles
+        validation of the `state` arg.
+
+        :param entity: The entity that is being updated
+        :param state: The state to update to
+        """
+        endpoint = self.detail_endpoint(guid=entity["guid"], **kwargs)
+        self._process_api_request("patch", endpoint, state=state.value)
