@@ -119,6 +119,10 @@ class QalxStepFunctionNotDefined(QalxError):
     """A specific Bot step function has not been defined by the user"""
 
 
+class QalxFileRetrievalError(QalxError):
+    """Error when retrieving a file from qalx"""
+
+
 class QalxFactoryError(QalxError):
     """Generic error with a Qalx factory"""
 
