@@ -1,6 +1,7 @@
 from collections import namedtuple
 
-from pyqalx.core.errors import QalxInvalidTagError
+from pyqalx.core.adapters.adapter import QalxAdapter
+from pyqalx.core.errors import QalxInvalidTagError, QalxAPIResponseError
 
 
 class Tags(list):
@@ -61,14 +62,15 @@ class Tags(list):
         if not isinstance(tags, list):
             tags = [tags]
         if len(tags):
+            # Non standard endpoint so cannot use a QalxSession instance
             success, data = self.rest_api.post(
                 "tags/validate", json={"tags": tags}
             )
             if not success:
-                m = "API request error, message:\n\n-vvv-\n\n"
-                m += "\n".join([f"{k}: {v}" for k, v in data.items()])
-                m += "\n\n-^^^-"
-                raise QalxInvalidTagError(m)
+                try:
+                    QalxAdapter.raise_api_response_error(data)
+                except QalxAPIResponseError as exc:
+                    raise QalxInvalidTagError(exc)
 
     def add(self, name, value):
         """
