@@ -235,10 +235,10 @@ class BotTabulation(QalxCLITabulation):
         return [
             "Index",
             "Name",
-            "Status",
+            "State",
             "Platform",
             "Node",
-            "No. Workers",
+            "No. Workers (Active/Total)",
             "Created On (UTC)",
             "Created By",
         ]
@@ -246,13 +246,16 @@ class BotTabulation(QalxCLITabulation):
     @staticmethod
     def build_row(index, entity):
         created_on = entity.info.created.on.strftime("%d/%m/%Y %H:%M:%S")
+        num_active_workers = len(
+            [worker for worker in entity.workers if worker.state == "active"]
+        )
         row = [
             index,
             entity.name,
-            entity.status,
+            entity.state,
             entity.host.get("platform"),
             entity.host.get("node"),
-            len(entity.workers),
+            f"{num_active_workers}/{len(entity.workers)}",
             created_on,
             entity.info.created.by.email,
         ]
